@@ -1,6 +1,6 @@
 /* ====================================================================
- * Copyright (c) 1999-2004 Ralf S. Engelschall <rse@engelschall.com>
- * Copyright (c) 1999-2004 The OSSP Project <http://www.ossp.org/>
+ * Copyright (c) 1999-2006 Ralf S. Engelschall <rse@engelschall.com>
+ * Copyright (c) 1999-2006 The OSSP Project <http://www.ossp.org/>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -331,6 +331,7 @@ typedef void MM;
 /* Global Malloc-Replacement API */
 int     MM_create(size_t, const char *);
 int     MM_permission(mode_t, uid_t, gid_t);
+void    MM_reset(void);
 void    MM_destroy(void);
 int     MM_lock(mm_lock_mode);
 int     MM_unlock(void);
@@ -347,6 +348,7 @@ char   *MM_error(void);
 /* Standard Malloc-Style API */
 MM     *mm_create(size_t, const char *);
 int     mm_permission(MM *, mode_t, uid_t, gid_t);
+void    mm_reset(MM *);
 void    mm_destroy(MM *);
 int     mm_lock(MM *, mm_lock_mode);
 int     mm_unlock(MM *);
